Welcome to PymoNNtorch's documentation!
======================================

.. image:: https://raw.githubusercontent.com/cnrl/PymoNNtorch/main/docs/_images/pymoNNtorch-logo-t-256.png
    :width: 256
    :alt: pymonntorch logo

|


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   tutorial
   documentation
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
